==> megasync-oldherl-debug-5.4.1.0-3-x86_64.pkg.tar.zst: usr/src/debug/megasync-oldherl/MEGAsync/src/MEGASync/syncs/gui/Backups/BackupSettingsElements.cpp <==
#include "BackupSettingsElements.h"
#include "ui_OpenBackupsFolder.h"

#include <syncs/gui/SyncSettingsUIBase.h>
#include "UserAttributesRequests/MyBackupsHandle.h"

BackupSettingsElements::BackupSettingsElements(QObject *parent)
    :QObject(parent)
    ,openFolderUi(new Ui::OpenBackupsFolder)
    ,mOpenBackupsFolder(nullptr)
{
}

BackupSettingsElements::~BackupSettingsElements()
{
    delete openFolderUi;
}

void BackupSettingsElements::initElements(SyncSettingsUIBase *syncSettingsUi)
{
    mOpenBackupsFolder = new QWidget();
    openFolderUi->setupUi(mOpenBackupsFolder);
    openFolderUi->bOpenBackupFolder->setEnabled(false);
    openFolderUi->bOpenBackupFolder->setAutoDefault(false);
    connect(openFolderUi->bOpenBackupFolder, &QPushButton::clicked, this, &BackupSettingsElements::onOpenBackupFolderClicked);

    auto myBackupsHandle = UserAttributes::MyBackupsHandle::requestMyBackupsHandle();
    connect(myBackupsHandle.get(), &UserAttributes::MyBackupsHandle::attributeReady,
            this, &BackupSettingsElements::onMyBackupsFolderHandleSet);
    onMyBackupsFolderHandleSet(myBackupsHandle->getMyBackupsHandle());

    syncSettingsUi->insertUIElement(mOpenBackupsFolder, 0);
}

void BackupSettingsElements::updateUI()
{
    QString backupsDirPath = UserAttributes::MyBackupsHandle::getMyBackupsLocalizedPath();
    openFolderUi->lBackupFolder->setText(backupsDirPath);
}

void BackupSettingsElements::retranslateUI()
{
    updateUI();
    openFolderUi->retranslateUi(mOpenBackupsFolder);
}

void BackupSettingsElements::onOpenBackupFolderClicked()
{
    auto myBackupsHandle = UserAttributes::MyBackupsHandle::requestMyBackupsHandle();
    Utilities::openInMega(myBackupsHandle->getMyBackupsHandle());
}

void BackupSettingsElements::onMyBackupsFolderHandleSet(mega::MegaHandle h)
{
    updateUI();
    openFolderUi->bOpenBackupFolder->setEnabled(h != mega::INVALID_HANDLE);
}

==> megasync-oldherl-debug-6.0.0.3-4-x86_64.pkg.tar.zst: usr/src/debug/megasync-oldherl/MEGAsync/src/MEGASync/syncs/gui/Backups/BackupSettingsElements.cpp <==
#include "BackupSettingsElements.h"

#include "MegaApplication.h"
#include "MyBackupsHandle.h"
#include "SyncSettingsUIBase.h"
#include "ui_OpenBackupsFolder.h"
#include "Utilities.h"

BackupSettingsElements::BackupSettingsElements(QObject* parent):
    QObject(parent),
    openFolderUi(new Ui::OpenBackupsFolder),
    mOpenBackupsFolder(nullptr)
{}

BackupSettingsElements::~BackupSettingsElements()
{
    delete openFolderUi;
}

void BackupSettingsElements::initElements(SyncSettingsUIBase* syncSettingsUi)
{
    mOpenBackupsFolder = new QWidget();
    openFolderUi->setupUi(mOpenBackupsFolder);
    openFolderUi->bOpenBackupFolder->setEnabled(false);
    openFolderUi->bOpenBackupFolder->setAutoDefault(false);
    connect(openFolderUi->bOpenBackupFolder,
            &QPushButton::clicked,
            this,
            &BackupSettingsElements::onOpenBackupFolderClicked);

    auto myBackupsHandle = UserAttributes::MyBackupsHandle::requestMyBackupsHandle();
    connect(myBackupsHandle.get(),
            &UserAttributes::MyBackupsHandle::attributeReady,
            this,
            &BackupSettingsElements::onMyBackupsFolderHandleSet);
    onMyBackupsFolderHandleSet(myBackupsHandle->getMyBackupsHandle());

    syncSettingsUi->insertUIElement(mOpenBackupsFolder, 0);
}

void BackupSettingsElements::updateUI()
{
    QString backupsDirPath = UserAttributes::MyBackupsHandle::getMyBackupsLocalizedPath();
    openFolderUi->lBackupFolder->setText(backupsDirPath);
}

void BackupSettingsElements::retranslateUI()
{
    updateUI();
    openFolderUi->retranslateUi(mOpenBackupsFolder);
}

void BackupSettingsElements::onOpenBackupFolderClicked()
{
    auto myBackupsHandle = UserAttributes::MyBackupsHandle::requestMyBackupsHandle();
    Utilities::openInMega(myBackupsHandle->getMyBackupsHandle());
}

void BackupSettingsElements::onMyBackupsFolderHandleSet(mega::MegaHandle h)
{
    updateUI();
    openFolderUi->bOpenBackupFolder->setEnabled(h != mega::INVALID_HANDLE);
}
